# -*- coding: utf-8 -*-

from django.urls import re_path


class LinkClassMixin:
    link_classes = None

    def get_link_classes(self):
        if self.link_classes:
            return self.link_classes
        raise NotImplementedError("'object_tool_classes' not implemented")

    def changelist_view(self, request, extra_context=None):
        extra_context = self.get_object_tools_extra_context(request, extra_context)
        return super().changelist_view(request, extra_context)

    def get_object_tools_extra_context(self, request, extra_context=None):
        extra_context = extra_context or {}
        extra_context['object_tools'] = self.get_object_tools(request)
        return extra_context

    def get_object_tools(self, request):
        my_ot = []
        for link_class in self.get_link_classes():
            if link_class.button is True:
                my_ot.append({'admin_urlname': link_class.url, 'title': link_class.title})
        return my_ot

    def get_urls(self):
        urls = super().get_urls()
        my_urls = []
        for link_class in self.get_link_classes():
            my_urls.append(
                re_path(
                    r'^{}/$'.format(link_class.url),
                    self.admin_site.admin_view(link_class.view_class.as_view()),
                    name='{}_{}_{}'.format(
                        self.model._meta.app_label, self.model._meta.model_name, link_class.url_name
                    )
                )
            )
        return my_urls + urls
